@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_USTRING_H
 #define _GLIBMM_USTRING_H
 
-/* $Id: ustring.h,v 1.8 2004/12/18 23:52:44 murrayc Exp $ */
+/* $Id: ustring.h,v 1.12.2.1 2006/04/19 11:54:50 murrayc Exp $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -232,7 +232,13 @@ public:
 
 #endif /* GLIBMM_HAVE_SUN_REVERSE_ITERATOR */
 
-  static const size_type npos = std::string::npos;
+#ifdef GLIBMM_HAVE_ALLOWS_STATIC_INLINE_NPOS
+  static GLIBMM_API const size_type npos = std::string::npos;
+#else
+  //The IRIX MipsPro compiler says "The indicated constant value is not known",
+  //so we need to initalize the static member data elsewhere.
+  static GLIBMM_API const size_type npos;
+#endif
 
   /*! Default constructor, which creates an empty string.
    */
@@ -564,7 +570,7 @@ public:
 //! @{
 
   /*! Returns a new UTF-8 string with all characters characters converted to
-   * their lowercase equivalent, while honoring the current locale.  The
+   * their uppercase equivalent, while honoring the current locale.  The
    * resulting string may change in the number of bytes as well as in the
    * number of characters.  For instance, the German sharp&nbsp;s
    * <tt>&quot;&szlig;&quot;</tt> will be replaced by two characters
@@ -598,7 +604,23 @@ private:
   template <class In, class ValueType = typename Glib::IteratorTraits<In>::value_type>
 #endif
   struct SequenceToString;
+  
+  //The Tru64 compiler needs these partial specializations to be declared here,
+  //as well as defined later. That's probably correct. murrayc.
+  template <class In>
+  struct SequenceToString<In, char>;
 
+  template <class In>
+  struct SequenceToString<In, gunichar>;
+  
+  /*
+  template <>
+  struct ustring::SequenceToString<Glib::ustring::iterator, gunichar>;
+
+  template <>
+  struct ustring::SequenceToString<Glib::ustring::const_iterator, gunichar>;
+  */
+  
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
   std::string string_;
@@ -612,25 +634,25 @@ struct ustring::SequenceToString
 {};
 
 template <class In>
-struct ustring::SequenceToString<In,char> : public std::string
+struct ustring::SequenceToString<In, char> : public std::string
 {
   SequenceToString(In pbegin, In pend);
 };
 
 template <class In>
-struct ustring::SequenceToString<In,gunichar> : public std::string
+struct ustring::SequenceToString<In, gunichar> : public std::string
 {
   SequenceToString(In pbegin, In pend);
 };
 
 template <>
-struct ustring::SequenceToString<Glib::ustring::iterator,gunichar> : public std::string
+struct ustring::SequenceToString<Glib::ustring::iterator, gunichar> : public std::string
 {
   SequenceToString(Glib::ustring::iterator pbegin, Glib::ustring::iterator pend);
 };
 
 template <>
-struct ustring::SequenceToString<Glib::ustring::const_iterator,gunichar> : public std::string
+struct ustring::SequenceToString<Glib::ustring::const_iterator, gunichar> : public std::string
 {
   SequenceToString(Glib::ustring::const_iterator pbegin, Glib::ustring::const_iterator pend);
 };
